@@ -52,6 +52,7 @@ Circuit::Circuit( qreal x, qreal y, qreal width, qreal height, CircuitView*  par
     m_loading    = false;
     m_conStarted = false;
     m_createSubc = false;
+    m_fastMode   = false;
     m_acceptKeys = true;
 
     m_board = NULL;
@@ -205,7 +206,7 @@ void Circuit::loadStrDoc( QString &doc )
         {
             if( !lastComp ) continue;
             SubCircuit* subci = static_cast<SubCircuit*>(lastComp);
-            Component* mComp = subci->getMainComp();
+            Component* mComp = subci->getMainComp();      // Old circuits with only 1 MainComp
             if( !mComp ) continue;
 
             QString propName = "";
@@ -219,8 +220,13 @@ void Circuit::loadStrDoc( QString &doc )
                     continue;
                 }
                 else if( prop.endsWith("/>") ) continue;
-                if( propName == "MainCompId") mComp = subci->getMainComp( prop.toString() );  // If more than 1 mainComp then get Component
-                else                          mComp->setPropStr( propName, prop.toString() );
+                if( propName == "MainCompId")  // If more than 1 mainComp then get Component
+                {
+                    QString compName = prop.toString();
+                    mComp = subci->getMainComp( compName );
+                    if( !mComp ) qDebug() << "ERROR: Could not create Main Component:"<< compName;
+                }
+                else if( mComp ) mComp->setPropStr( propName, prop.toString() );
 
                 propName = "";
             }
@@ -471,6 +477,7 @@ QString Circuit::circuitHeader()
     header += "stepsPS=\""+QString::number( m_simulator->stepsPerSec() )+"\" ";
     header += "NLsteps=\""+QString::number( m_simulator->maxNlSteps() )+"\" ";
     header += "reaStep=\""+QString::number( m_simulator->reactStep() )+"\" ";
+    header += "fastMode=\""+QString::number( m_fastMode )+"\" ";
     header += "animate=\""+QString::number( m_animate )+"\" >\n";
     return header;
 }
