@@ -51,6 +51,9 @@ class MAINMODULE_EXPORT Circuit : public QGraphicsScene
         int autoBck();
         void setAutoBck( int secs );
 
+        bool fastMode() { return m_fastMode; }
+        void setFastMode( bool fast ) { m_fastMode = fast; }
+
         void removeItems();
         void removeComp( Component* comp );
         void clearCircuit();
@@ -60,7 +63,7 @@ class MAINMODULE_EXPORT Circuit : public QGraphicsScene
         void unSaveState();
         void addCompState( CompBase* c, QString p, stateMode=stateAll );
 
-        void setChanged() { m_changed = true; }
+        void setChanged();
 
         void deselectAll();
         void accepKeys( bool a ) { m_acceptKeys = a; }
@@ -105,6 +108,7 @@ class MAINMODULE_EXPORT Circuit : public QGraphicsScene
         void updatePin( ePin* epin, QString oldId, QString newId );
 
         const QString getFilePath() const { return m_filePath; }
+        void setFilePath( QString f ) { m_filePath = f; }
 
         void drawBackground( QPainter* painter, const QRectF &rect );
 
@@ -183,6 +187,7 @@ class MAINMODULE_EXPORT Circuit : public QGraphicsScene
         bool m_redo;
         bool m_acceptKeys;
         bool m_createSubc;
+        bool m_fastMode;
 
         QPointF m_eventpoint;
         QPointF m_deltaMove;
