@@ -52,6 +52,9 @@ void PropDialog::setComponent( Component* comp )
     {
         if( group.flags & groupHidden ) continue;
 
+        bool groupEnabled = true;
+        if( comp->parentItem() && (group.flags & groupNoCopy) ) groupEnabled = false;
+
         QList<ComProperty*> propList = group.propList;
         if( !propList.isEmpty() )
         {
@@ -88,6 +91,11 @@ void PropDialog::setComponent( Component* comp )
                 mp->setMinimumWidth( w );
                 m_propList.append( mp );
                 propWidget->layout()->addWidget( mp );
+
+                bool propEnabled = true;
+                if( comp->parentItem() && (prop->flags() & propNoCopy) ) propEnabled = false;
+
+                mp->setEnabled( groupEnabled && propEnabled );
             }
             propWidget->setMinimumHeight( propList.size()*30);
             propWidget->setMinimumWidth( w+40 );
