@@ -184,59 +184,59 @@ Mcu::Mcu( QObject* parent, QString type, QString id )
 
 void Mcu::setup( QString type )
 {
-    if     ( type == "iou" ) m_deviceType = typeIOU;
-    else if( type == "mpu" ) m_deviceType = typeMPU;
-    else if( type == "mcu" ) m_deviceType = typeMCU;
-    else                     m_deviceType = typeNONE;
+    slotmain();
 
-    //if( m_deviceType >= typeMPU )
-        slotmain(); //m_pSelf = this;
+// Main Property Group --------------------------------------
 
-    if( m_deviceType == typeMCU )
-    {
-    addPropGroup( { tr("Main"), {
-new DoubProp<Mcu>("Frequency", tr("Frequency")    ,"MHz", this, &Mcu::extFreq,    &Mcu::setExtFreq ),
-new StrProp <Mcu>("Program"  , tr("Firmware")        ,"", this, &Mcu::program,    &Mcu::setProgram ),
-new BoolProp<Mcu>("Auto_Load", tr("Reload hex at \
-                                   Simulation Start"),"", this, &Mcu::autoLoad,   &Mcu::setAutoLoad ),
-new BoolProp<Mcu>("saveEepr" , tr("EEPROM persitent"),"", this, &Mcu::saveEepr,   &Mcu::setSaveEepr ),
-new BoolProp<Mcu>("Logic_Symbol", tr("Logic Symbol") ,"", this, &Mcu::logicSymbol,&Mcu::setLogicSymbol, propNoCopy )
-    }, 0} );
+if( m_eMcu.m_intOsc )
+addProperty(tr("Main"),new DoubProp<Mcu>("Frequency", tr("Frequency"),"MHz", this, &Mcu::extFreq, &Mcu::setExtFreq ));
 
-    addPropGroup( { tr("Config"), {
-new ComProperty( "", tr("Changes applied after Simulation Restart"),"","",0),
-                    }, groupNoCopy} );
+if( m_eMcu.flashSize() )
+{
+addProperty(tr("Main"),new StrProp <Mcu>("Program"  , tr("Firmware"),"", this, &Mcu::program, &Mcu::setProgram ));
+addProperty(tr("Main"),new BoolProp<Mcu>("Auto_Load", tr("Reload hex at Simulation Start"),"", this, &Mcu::autoLoad, &Mcu::setAutoLoad ));
+}
+if( m_eMcu.romSize() )
+addProperty(tr("Main"),new BoolProp<Mcu>("saveEepr" , tr("EEPROM persitent"),"", this, &Mcu::saveEepr,   &Mcu::setSaveEepr ));
+
+if( QFileInfo::exists( m_pkgeFile.replace(".package","_LS.package") ) )
+addProperty(tr("Main"),new BoolProp<Mcu>( "Logic_Symbol", tr("Logic Symbol"),"", this, &Mcu::logicSymbol, &Mcu::setLogicSymbol, propNoCopy ) );
+
+
+// Config Property Group ------------------------------------
+
+propGroup cg = { tr("Config"), { new ComProperty( "", tr("Changes applied after Simulation Restart"),"","",0),}, groupNoCopy};
 
 if( m_portRstPin )
-addProperty(tr("Config"),new BoolProp<Mcu>("Rst_enabled", tr("Enable Reset Pin")   ,"", this, &Mcu::rstPinEnabled, &Mcu::enableRstPin ) );
+cg.propList.append(new BoolProp<Mcu>("Rst_enabled", tr("Enable Reset Pin")   ,"", this, &Mcu::rstPinEnabled, &Mcu::enableRstPin ) );
 
-if( m_eMcu.m_intOsc && m_eMcu.m_intOsc->clkInPin() )
-addProperty(tr("Config"),new BoolProp<Mcu>("Ext_Osc"    , tr("External Oscillator"),"", this, &Mcu::extOscEnabled, &Mcu::enableExtOsc ) );
+if( m_eMcu.m_intOsc /*&& m_eMcu.m_intOsc->clkInPin()*/ )
+cg.propList.append(new BoolProp<Mcu>("Ext_Osc"    , tr("External Oscillator"),"", this, &Mcu::extOscEnabled, &Mcu::enableExtOsc ) );
 
 if( m_eMcu.m_wdt )
-addProperty(tr("Config"),new BoolProp<Mcu>("Wdt_enabled", tr("Enable WatchDog")    ,"", this, &Mcu::wdtEnabled   , &Mcu::enableWdt ) );
+cg.propList.append(new BoolProp<Mcu>("Wdt_enabled", tr("Enable WatchDog")    ,"", this, &Mcu::wdtEnabled   , &Mcu::enableWdt ) );
 
 if( m_eMcu.m_intOsc && m_eMcu.m_intOsc->clkOutPin() )
-addProperty(tr("Config"),new BoolProp<Mcu>("Clk_Out"    , tr("Clock Out")          ,"", this, &Mcu::clockOut     , &Mcu::setClockOut ) );
+cg.propList.append(new BoolProp<Mcu>("Clk_Out"    , tr("Clock Out")          ,"", this, &Mcu::clockOut     , &Mcu::setClockOut ) );
 
-    addPropGroup( {"Hidden", {
-new StrProp<Mcu>("varList"  ,"","", this, &Mcu::varList,   &Mcu::setVarList),
-new StrProp<Mcu>("cpuRegs"  ,"","", this, &Mcu::cpuRegs,   &Mcu::setCpuRegs),
-new StrProp<Mcu>("eeprom"   ,"","", this, &Mcu::getEeprom, &Mcu::setEeprom ),
-new IntProp<Mcu>("SerialMon","","", this, &Mcu::serialMon, &Mcu::setSerialMon )
-    }, groupHidden } );
-    }
-    else //if( m_deviceType == typeMPU )
-    {
-//addProperty(tr("Main"),new DoubProp<Mcu>( "Frequency"   , tr("Frequency"),"MHz" , this, &Mcu::freq,    &Mcu::setFreq ) );
-addProperty(tr("Main"),new BoolProp<Mcu>( "Logic_Symbol", tr("Logic Symbol"),"", this, &Mcu::logicSymbol, &Mcu::setLogicSymbol ) );
+if( cg.propList.size() > 1 ) addPropGroup( cg );
 
-    addPropGroup( {"Hidden", {
-new StrProp<Mcu>("varList", "","", this, &Mcu::varList,   &Mcu::setVarList),
-new StrProp<Mcu>("cpuRegs", "","", this, &Mcu::cpuRegs,   &Mcu::setCpuRegs),
-new StrProp<Mcu>("Links"  , "","", this, &Mcu::getLinks , &Mcu::setLinks )
-    }, groupHidden } );
-    }
+
+// Hidden Property Group -----------------------------------
+
+propGroup hi = {"Hidden", {}, groupHidden };
+
+cg.propList.append(new StrProp<Mcu>("varList"  ,"","", this, &Mcu::varList,   &Mcu::setVarList) );
+cg.propList.append(new StrProp<Mcu>("cpuRegs"  ,"","", this, &Mcu::cpuRegs,   &Mcu::setCpuRegs) );
+cg.propList.append(new StrProp<Mcu>("Links"    ,"","", this, &Mcu::getLinks , &Mcu::setLinks ) );
+
+if( m_eMcu.romSize() )
+cg.propList.append(new StrProp<Mcu>("eeprom"   ,"","", this, &Mcu::getEeprom, &Mcu::setEeprom ) );
+
+if( m_eMcu.m_usarts.size() )
+cg.propList.append(new IntProp<Mcu>("SerialMon","","", this, &Mcu::serialMon, &Mcu::setSerialMon ) );
+
+if( hi.propList.size() > 0 ) addPropGroup( hi );
 }
 Mcu::~Mcu()
 {
@@ -278,6 +278,8 @@ void Mcu::stamp()
 
 void Mcu::updateStep()
 {
+    if( m_backImage ) update();  // used by ScriptDisplay
+
     if( m_crashed )
     {
         Simulator::self()->setWarning( /*m_warning*/0 );
@@ -286,7 +288,7 @@ void Mcu::updateStep()
     if( m_mcuMonitor
      && m_mcuMonitor->isVisible() ) m_mcuMonitor->updateStep();
 
-    m_eMcu.cpu->updateStep();
+    m_eMcu.m_cpu->updateStep();
 }
 
 void Mcu::voltChanged() // Reset Pin callBack
@@ -327,10 +329,10 @@ void Mcu::setVarList( QString vl )
 //{ m_eMcu.getRamTable()->loadVarSet( vl.split(",") ); }
 
 QString Mcu::cpuRegs()
-{ return m_eMcu.getCpuTable()->getVarSet().join(","); }
+{ return m_eMcu.getWatcher()->getVarSet().join(","); }
 
 void Mcu::setCpuRegs( QString vl )
-{ m_eMcu.getCpuTable()->loadVarSet( vl.split(",") ); }
+{ m_eMcu.getWatcher()->loadVarSet( vl.split(",") ); }
 
 void Mcu::setEeprom( QString eep )
 {
@@ -436,14 +438,12 @@ void Mcu::contextMenuEvent( QGraphicsSceneContextMenuEvent* event )
         menu->deleteLater();
 }   }
 
-void Mcu::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu )
+void Mcu::contextMenu( QGraphicsSceneContextMenuEvent*, QMenu* menu )
 {
-    //if( m_deviceType >= typeMPU )
-    {
-        QAction* mainAction = menu->addAction( QIcon(":/subc.png"),tr("Main Mcu") );
-        connect( mainAction, &QAction::triggered,
-                       this, &Mcu::slotmain, Qt::UniqueConnection );
-    }
+
+    QAction* mainAction = menu->addAction( QIcon(":/subc.png"),tr("Main Mcu") );
+    connect( mainAction, &QAction::triggered,
+                   this, &Mcu::slotmain, Qt::UniqueConnection );
 
     if( m_scriptLink )
     {
@@ -452,7 +452,7 @@ void Mcu::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu )
                            this, &Mcu::slotLinkComp, Qt::UniqueConnection );
     }
 
-    if( m_deviceType == typeMCU )
+    if( m_eMcu.flashSize() )
     {
         QAction* loadAction = menu->addAction( QIcon(":/load.svg"),tr("Load firmware") );
         connect( loadAction, &QAction::triggered,
@@ -463,7 +463,10 @@ void Mcu::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu )
                          this, &Mcu::slotReload, Qt::UniqueConnection );
 
         menu->addSeparator();
+    }
 
+    if( m_eMcu.romSize() )
+    {
         QAction* loadDaAction = menu->addAction( QIcon(":/open.png"),tr("Load EEPROM data from file") );
         connect( loadDaAction, &QAction::triggered,
                          this, &Mcu::loadEEPROM, Qt::UniqueConnection );
@@ -472,15 +475,13 @@ void Mcu::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu )
         connect( saveDaAction, &QAction::triggered,
                          this, &Mcu::saveEEPROM, Qt::UniqueConnection );
     }
-    //if( m_deviceType >= typeMPU )
-    {
-        menu->addSeparator();
+    menu->addSeparator();
 
-        QAction* openRamTab = menu->addAction( QIcon(":/terminal.svg"),tr("Open Mcu Monitor.") );
-        connect( openRamTab, &QAction::triggered,
-                       this, &Mcu::slotOpenMcuMonitor, Qt::UniqueConnection );
-    }
-    if( m_deviceType == typeMCU )
+    QAction* openRamTab = menu->addAction( QIcon(":/terminal.svg"),tr("Open Mcu Monitor.") );
+    connect( openRamTab, &QAction::triggered,
+                   this, &Mcu::slotOpenMcuMonitor, Qt::UniqueConnection );
+
+    if( m_eMcu.m_usarts.size() )
     {
         QMenu* serMonMenu = menu->addMenu( tr("Open Serial Monitor.") );
 
@@ -494,14 +495,6 @@ void Mcu::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu )
         connect( sm, QOverload<int>::of(&QSignalMapper::mapped), this, &Mcu::slotOpenTerm );
     }
     menu->addSeparator();
-
-    /*if( !event )
-    {
-        QAction* propertiesAction = menu->addAction( QIcon( ":/properties.svg"),tr("Properties") );
-        connect( propertiesAction, &QAction::triggered,
-                             this, &Mcu::slotProperties, Qt::UniqueConnection );
-        menu->addSeparator();
-    }*/
 }
 
 void Mcu::slotmain()
@@ -541,7 +534,7 @@ int Mcu::serialMon()
 
 void Mcu::setSerialMon( int s ) { if( s>=0 ) slotOpenTerm( s ); }
 
-void Mcu::setLinkedValue( int v, int i )
+void Mcu::setLinkedValue( double v, int i )
 {
     if( m_scriptLink ) m_scriptLink->setLinkedVal( v, i );
 }
@@ -552,7 +545,7 @@ void Mcu::setLinkedString( QString str, int i )
 }
 
 Pin* Mcu::addPin( QString id, QString type, QString label,
-                  int pos, int xpos, int ypos, int angle, int length )
+                  int pos, int xpos, int ypos, int angle, int length, int space )
 {
     IoPin* pin = NULL;
     if( type.contains("rst") )
@@ -579,6 +572,7 @@ Pin* Mcu::addPin( QString id, QString type, QString label,
     pin->setPos( QPoint( xpos, ypos ) );
     pin->setPinAngle( angle );
     pin->setLength( length );
+    pin->setSpace( space );
     pin->setLabelText( label );
     pin->setLabelColor( color );
     pin->setFlag( QGraphicsItem::ItemStacksBehindParent, false );
@@ -631,8 +625,8 @@ bool Mcu::clockOut()
 
 void Mcu::setClockOut( bool clkOut ) { if( m_eMcu.m_intOsc ) m_eMcu.m_intOsc->setClockOut( clkOut ); }
 
-QStringList Mcu::getEnumUids( QString e) { return m_eMcu.cpu->getEnumUids( e ); }
-QStringList Mcu::getEnumNames( QString e) { return m_eMcu.cpu->getEnumNames( e ); }
+QStringList Mcu::getEnumUids( QString e) { return m_eMcu.m_cpu->getEnumUids( e ); }
+QStringList Mcu::getEnumNames( QString e) { return m_eMcu.m_cpu->getEnumNames( e ); }
 
 void Mcu::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget )
 {
